diff --git a/css/public.css b/css/public.css
index eb4b36c..b297bae 100755
--- a/css/public.css
+++ b/css/public.css
@@ -4,9 +4,9 @@
* Created-Date: 15.05.14
* Created-Time: 16:21
* Since: 1.0
- * Version: 2.0.9d0
+ * Version: 2.0.9d1
*
- * Last modified: 2020-11-07T1424+0100
+ * Last modified: 2020-11-07T1608+0100
*/
diff --git a/css/settings.css b/css/settings.css
index 05f1e32..6342f5b 100755
--- a/css/settings.css
+++ b/css/settings.css
@@ -4,8 +4,9 @@
* Created-Date: 15.05.14
* Created-Time: 16:21
* Since: 1.0
- * Version: 2.0.9
- * Last modified: 2020-11-06T2321+0100
+ * Version: 2.0.9d1
+ *
+ * Last modified: 2020-11-07T1608+0100
*/
diff --git a/footnotes.php b/footnotes.php
index 6e42b1b..d8c59de 100755
--- a/footnotes.php
+++ b/footnotes.php
@@ -4,7 +4,7 @@
Plugin URI: https://wordpress.org/plugins/footnotes/
Description: time to bring footnotes to your website! footnotes are known from offline publishing and everybody takes them for granted when reading a magazine.
Author: Mark Cheret
- Version: 2.0.9d0
+ Version: 2.0.9d1
Author URI: http://cheret.de/plugins/footnotes-2/
Text Domain: footnotes
Domain Path: /languages
diff --git a/readme.txt b/readme.txt
index 4141b4b..e64ca30 100755
--- a/readme.txt
+++ b/readme.txt
@@ -80,6 +80,9 @@ Visit this swift write-up from a **footnotes** user by the name of **Southwest**
== Changelog ==
+= 2.0.9d1 =
+- Bugfix: Re-added jQuery UI from third party to look whether it can fix a broken tooltip display 2020-11-07T1604+0100
+
= 2.0.9d0 =
- Bugfix: Layout: Footnote referrers: more efficiently disable underline unless hovered
diff --git a/class/init.php b/class/init.php
index cba5582..427c680 100644
--- a/class/init.php
+++ b/class/init.php
@@ -2,16 +2,16 @@
/**
* Includes the main Class of the Plugin.
*
- * ***********************************************************************************************
- * IMPORTANT: In registerPublic() line 134: keep plugin version # up to date for cache busting. *
- * ***********************************************************************************************
+ * ******************************************************************************************************
+ * IMPORTANT: In registerPublic() line 134: Please keep plugin version # up to date for cache busting. *
+ * ******************************************************************************************************
*
* @filesource
* @author Stefan Herndler
* @since 1.5.0 12.09.14 10:56
*
* Edited for v1.6.5: Replaced deprecated function create_function()
- * Edited for v2.0.0: Added jQueryUI from CDN 2020-10-26T1907+0100
+ * Edited for v2.0.0: Added jQueryUI from Cloudflare 2020-10-26T1907+0100
* Edited for v2.0.3: Added style sheet versioning 2020-10-29T1413+0100
* Edited for v2.0.4: Added jQuery UI from WordPress 2020-11-01T1902+0100
*
@@ -108,7 +108,8 @@ class MCI_Footnotes {
* @author Stefan Herndler
* @since 1.5.0
*
- * Updated for v2.0.4 by adding jQueryUI from WordPress following @check2020de:
+ * Updated for v2.0.0 adding jQuery UI
+ * Updated for v2.0.4 by adding jQuery UI from WordPress following @check2020de:
*
* See
*
@@ -116,24 +117,40 @@ class MCI_Footnotes {
*/
public function registerPublic() {
- // add the jQuery plugin (already registered by WordPress)
+ ### SCRIPTS
+
+ // add the jQuery plugin registered by WordPress
wp_enqueue_script( 'jquery' );
- // Add jQueryUI: 'no need to enqueue -core, because dependencies are set'
+
+ // Add the jQuery UI libraries registered by WordPress:
+ // 'no need to enqueue -core, because dependencies are set'
+ // Source:
wp_enqueue_script( 'jquery-ui-widget' );
wp_enqueue_script( 'jquery-ui-mouse' );
wp_enqueue_script( 'jquery-ui-accordion' );
wp_enqueue_script( 'jquery-ui-autocomplete' );
wp_enqueue_script( 'jquery-ui-slider' );
+ // Should that not work, fetch jQuery UI from cdnjs.cloudflare.com:
+ // Add jQuery UI following @vonpiernik:
+ // :
+ // This was enabled in Footnotes v2.0.0 through v2.0.3.
+ // Re-added for 2.0.9d1 to look whether it can fix a broken tooltip display. 2020-11-07T1601+0100
+ wp_register_script( 'jQueryUI', 'https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js', null, null, true );
+ wp_enqueue_script( 'jQueryUI' );
+
// Add jQuery tools:
wp_enqueue_script('mci-footnotes-js-jquery-tools', plugins_url('../js/jquery.tools.min.js', __FILE__));
- // IMPORTANT: up-to-date plugin version number for cache busting:
+
+ ### STYLES
+
+ // IMPORTANT: up-to-date plugin version number NEEDED for cache busting:
wp_enqueue_style(
'mci-footnotes-css-public',
plugins_url('../css/public.css', __FILE__),
'',
- '2.0.9d0'
+ '2.0.9d1'
);
}